@@ -1,7 +1,7 @@
 #! /bin/sh
 
 cd tests
-. ./compat.sh
+. ../compat.sh
 
 ${DIR}/generate_sequence -v -o seq10m -m 10 -m 22 -s 3141592653 10000000
 ${DIR}/generate_sequence -v -o seq1m -s 1040104553 1000000 1000000 1000000 1000000 1000000
@@ -17,3 +17,7 @@ if [ -n "$SAMTOOLS" ]; then
     $SAMTOOLS view -b -o seq10m.bam seq10m.sam
     $SAMTOOLS view -C -o seq10m.cram seq10m.sam
 fi
+
+if [ -n "$UNIX2DOS" ]; then
+    $UNIX2DOS -n seq10m.fa seq10mDOS.fa
+fi
